package com.chinaitop.depot.keeperAccount.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import com.chinaitop.depot.utils.ParameterUtil;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.stereotype.Service;

import com.chinaitop.depot.keeperAccount.mapper.StorageAccountRecordMapper;
import com.chinaitop.depot.keeperAccount.model.StorageAccountRecord;
import com.chinaitop.depot.keeperAccount.model.StorageAccountRecordExample;
import com.chinaitop.depot.keeperAccount.service.StorageAccountRecordService;
import com.github.pagehelper.PageInfo;

@Service
public class StorageAccountRecordServiceImpl implements StorageAccountRecordService {

	@Resource
	private StorageAccountRecordMapper mapper;

	@Override
	public void add(StorageAccountRecord record) {
		mapper.insertSelective(record);
	}

	@Override
	public void update(StorageAccountRecord record) {
		mapper.updateByPrimaryKeySelective(record);
	}

	@Override
	public List<StorageAccountRecord> findByConditon(StorageAccountRecordExample example) {
		return mapper.selectByExample(example);
	}

	@Override
	public Map<String, Object> selectOrCheckStorageAccountRecord(HttpServletRequest request, String houseId, String wareId, Integer hwxz,
			Integer lspz, String rq, Integer accountType, Map<String, Object> map) {
		String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"),"");
		
		StorageAccountRecord record = null;
		StorageAccountRecordExample example = new StorageAccountRecordExample();
		StorageAccountRecordExample.Criteria criteria = example.createCriteria();
		if (houseId != null && !"".equals(houseId)) {
			criteria.andHouseIdEqualTo(houseId);
		}
		if (wareId != null && !"".equals(wareId)) {
			criteria.andWareIdEqualTo(wareId);
		}
		criteria.andHwxzEqualTo(hwxz);
		criteria.andLspzEqualTo(lspz);
		criteria.andAccountTypeEqualTo(accountType);
		criteria.andOrgIdEqualTo(Integer.parseInt(orgId));
		if (accountType == 1) {
			criteria.andRqEqualTo(rq);
		} else {
			criteria.andRqEqualTo(rq);
		}

		List<StorageAccountRecord> list = mapper.selectByExample(example);
		if (null != list && list.size() > 0) {
			record = list.get(0);
		} else {
			record = new StorageAccountRecord();
		}
		map.put("obj", record);

		return map;
	}

	@Override
	public List<Map<String, Object>> selectKeepSumAccountData(Map<String, Object> map) {
		return mapper.selectKeepSumAccount(map);
	}

	@Override
	public List<Map<String, Object>> selectKCSL(Map<String, Object> map) {
		return mapper.selectKCSL(map);
	}

	@Override
	public List<Map<String, Object>> selectAccountGroup(Map<String, Object> map) {
		return mapper.selectAccountGroup(map);
	}

	@Override
	public List<Map<String, Object>> getGroupByList(HttpServletRequest request, Integer lspz, Integer lsxz) {
		String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"),"");
		Map<String, Object> map = new HashMap<String, Object>();
		if (lspz != null) {
			map.put("pz", lspz+"");
		}
		if (lsxz != null) {
			map.put("hwxz", lsxz+"");
		}
		if (orgId != null) {
			map.put("orgId", orgId);
		}
		List<Map<String, Object>> list = mapper.selectKeepSumAccount(map);
		return list;
	}

	@Override
	public PageInfo<Map<String, Object>> setListData(HttpServletRequest request, PageInfo<Map<String, Object>> pageInfo) {
		String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"),"");
		if (null != pageInfo.getList() && pageInfo.getList().size() > 0) {
			Map<String, Object> kcsl_map = null;
			List<Map<String, Object>> group_list = null;
			for (Map<String, Object> obj : pageInfo.getList()) {
				kcsl_map = new HashMap<String, Object>();
				kcsl_map.put("pz", obj.get("lspz"));
				kcsl_map.put("hwxz", obj.get("hwxz"));
				kcsl_map.put("rq", obj.get("rq"));
				kcsl_map.put("orgId", orgId == "" ? null : Integer.parseInt(orgId));
				//查询这个条件下有多少库存数量
				group_list = mapper.selectAccountGroup(kcsl_map);
				if (null != group_list && group_list.size() > 0) {
					obj.put("kcsl", group_list.get(0).get("kcsl"));
				}
			}
		}
		return pageInfo;
	}

	@Override
	public Map<String, Object> getCountSumAccountzl(Integer orgId, Integer lspz, Integer lsxz) {
		Map<String, Object> map = new HashMap<String, Object>();
		if (lspz != null) {
			map.put("pz", lspz+"");
		}
		if (lsxz != null) {
			map.put("hwxz", lsxz+"");
		}

		if (null != orgId && !"".equals(orgId)) {
			map.put("orgId", orgId);
		}
		return mapper.getCountSumAccountzl(map);
	}
}
