package com.chinaitop.depot.keeperPrint.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import com.chinaitop.depot.keeperAccount.model.StorageAccountRecord;
import com.chinaitop.depot.keeperPrint.model.StorageAccountPrintTotal;
import com.chinaitop.depot.keeperPrint.service.AccountPrintTotalService;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/StorageAccountPrintTotal")
@Api(value= "AccountPrintTotalController", description = "保管账记账控制类")
public class AccountPrintTotalController {

	@Resource
	private AccountPrintTotalService printTotalService;

	@RequestMapping(value="/printTotalList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="分仓账列表，按月统计", notes = "支持分页")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="pageNum", value="页数", paramType="query"),
    	@ApiImplicitParam(name="pageSize", value="每页显示条数", paramType="query"),
    	@ApiImplicitParam(name="orgId", value="组织机构ID", paramType="query"),
    	@ApiImplicitParam(name="ch", value="仓房id", paramType="query"),
    	@ApiImplicitParam(name="startDate", value="起始时间", paramType="query"),
    	@ApiImplicitParam(name="endDate", value="结束时间", paramType="query"),
    	@ApiImplicitParam(name="houseType", value="查询类型", paramType="query")
    })
	public PageInfo<StorageAccountPrintTotal> printTotalList(Integer pageNum, Integer pageSize, String orgId, String ch,String startDate, String endDate, Integer houseType) {

		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		List<StorageAccountPrintTotal> list = printTotalService.printTotalList(orgId, ch, startDate, endDate, houseType);
		PageInfo<StorageAccountPrintTotal> pageInfo = new PageInfo<StorageAccountPrintTotal>(list);
		return pageInfo;
	}

	@RequestMapping(value = "/saveAndUpdate", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="分仓账保存", notes = "分仓账保存")
	@ApiImplicitParams({
			@ApiImplicitParam(name="accountTotalJson", value="数据集", paramType="form")
	})
	public Map<String, Object> saveAndUpdate(String accountTotalJson) {
		Map<String, Object> map = new HashMap<String, Object>();
		ObjectMapper mapper = new ObjectMapper();
		try {
			StorageAccountPrintTotal record = mapper.readValue(accountTotalJson, StorageAccountPrintTotal.class);
			if (record.getId() == null) {
				printTotalService.add(record);
			} else {
				printTotalService.update(record);
			}
			map.put("status", "success");
			map.put("msg", "保存成功！");
		} catch (Exception e) {
			e.printStackTrace();
		}
		return map;
	}

	/**
	 * 根据主键id移除数据
	 * @param id
	 * @return
	 */
	@RequestMapping(value="/removePrintTotal", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
	@ApiOperation(value="根据主键id移除数据信息", notes = "根据主键id移除数据信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
	})
	public Map<String, Object> removePrintTotal(Integer id){
		Map<String,Object> retMap = new HashMap<String,Object>();
		if (null != id) {
			printTotalService.remove(id);
			retMap.put("msg","success");
		} else {
			retMap.put("msg","error");
		}
		return retMap;
	}

	/**
	 * 根据id加载对应数据
	 * @param id
	 * @return
	 */
	@RequestMapping(value = "loadDataById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="根据id加载对应数据", notes = "根据id加载对应数据")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "id", paramType = "query"),
	})
	public StorageAccountPrintTotal loadDataById(int id){
		return printTotalService.loadDataById(id);
	}
}
